@@ -32,6 +32,12 @@ SERVICE_VERSIONS = {
     "cam": [
         "2019-01-16"
     ],
+    "captcha": [
+        "2019-07-22"
+    ],
+    "car": [
+        "2022-01-10"
+    ],
     "cbs": [
         "2017-03-12"
     ],
@@ -44,10 +50,14 @@ SERVICE_VERSIONS = {
     "cfs": [
         "2019-07-19"
     ],
+    "cfw": [
+        "2019-09-04"
+    ],
     "chdfs": [
         "2020-11-12"
     ],
     "ciam": [
+        "2022-03-31",
         "2021-04-20"
     ],
     "ckafka": [
@@ -71,6 +81,9 @@ SERVICE_VERSIONS = {
     "cynosdb": [
         "2019-01-07"
     ],
+    "dataintegration": [
+        "2022-06-13"
+    ],
     "dayu": [
         "2018-07-09"
     ],
@@ -84,10 +97,20 @@ SERVICE_VERSIONS = {
     "dcdb": [
         "2018-04-11"
     ],
+    "dlc": [
+        "2021-01-25"
+    ],
     "dms": [
         "2020-08-19"
     ],
+    "dnspod": [
+        "2021-03-23"
+    ],
+    "domain": [
+        "2018-08-08"
+    ],
     "dts": [
+        "2021-12-06",
         "2018-03-30"
     ],
     "eb": [
@@ -129,6 +152,9 @@ SERVICE_VERSIONS = {
     "ims": [
         "2020-12-29"
     ],
+    "intlpartnersmgt": [
+        "2022-09-28"
+    ],
     "iotcloud": [
         "2021-04-08"
     ],
@@ -138,6 +164,9 @@ SERVICE_VERSIONS = {
     "kms": [
         "2019-01-18"
     ],
+    "lcic": [
+        "2022-08-17"
+    ],
     "lighthouse": [
         "2020-03-24"
     ],
@@ -172,6 +201,7 @@ SERVICE_VERSIONS = {
         "2018-11-19"
     ],
     "organization": [
+        "2021-03-31",
         "2018-12-25"
     ],
     "postgres": [
@@ -217,9 +247,18 @@ SERVICE_VERSIONS = {
     "tcaplusdb": [
         "2019-08-23"
     ],
+    "tchd": [
+        "2023-03-06"
+    ],
     "tcr": [
         "2019-09-24"
     ],
+    "tcss": [
+        "2020-11-01"
+    ],
+    "tdid": [
+        "2021-05-19"
+    ],
     "tdmq": [
         "2020-02-17"
     ],
@@ -227,6 +266,10 @@ SERVICE_VERSIONS = {
         "2021-07-01",
         "2020-12-21"
     ],
+    "teo": [
+        "2022-09-01",
+        "2022-01-06"
+    ],
     "tiw": [
         "2019-09-19"
     ],
@@ -236,10 +279,17 @@ SERVICE_VERSIONS = {
     "tms": [
         "2020-12-29"
     ],
+    "tmt": [
+        "2018-03-21"
+    ],
     "trtc": [
         "2019-07-22"
     ],
+    "tts": [
+        "2019-08-23"
+    ],
     "vm": [
+        "2021-09-22",
         "2020-12-29"
     ],
     "vod": [
